@@ -24,7 +24,7 @@ try:
 except ImportError:
     import Image
 
-__version__ = '1.0.3'
+__version__ = '1.0.5'
 
 PROGRAM_NAME = 'picopt'
 
@@ -302,8 +302,12 @@ def replace_ext(filename, new_ext):
 def new_percent_saved(report_stats):
     """spits out how much space the optimization saved"""
     size_in = report_stats.bytes_diff['in']
-    size_out = report_stats.bytes_diff['out']
-    percent_saved = (1 - (size_out / size_in)) * 100
+    if size_in != 0:
+        size_out = report_stats.bytes_diff['out']
+        ratio = size_out / size_in
+    else:
+        ratio = 0
+    percent_saved = (1 - ratio) * 100
 
     size_saved_kb = humanize_bytes(size_in - size_out)
     result = '%.*f%s (%s)' % (2, percent_saved, '%', size_saved_kb)
@@ -730,14 +734,20 @@ def record_timestamp(pathname_full, arguments):
     if arguments.test or arguments.list_only or not arguments.record_timestamp:
         return
     elif not arguments.follow_symlinks and os.path.islink(pathname_full):
+        if arguments.verbose:
+            print('Not setting timestamp because not following symlinks')
         return
     elif not os.path.isdir(pathname_full):
+        if arguments.verbose:
+            print('Not setting timestamp for a non-directory')
         return
 
     record_filename_full = os.path.join(pathname_full, RECORD_FILENAME)
     try:
         with open(record_filename_full, 'w'):
             os.utime(record_filename_full, None)
+        if arguments.verbose:
+            print("Set timestamp: %s" % record_filename_full)
     except IOError:
         print("Could not set timestamp in %s" % pathname_full)
 
@@ -790,9 +800,8 @@ def optimize_comic_archive(filename_full, image_format, arguments, multiproc,
     for result in result_set:
         result.wait()
 
-    pool = multiproc['pool']
     args = (filename_full, multiproc['in'], multiproc['out'], arguments)
-    return pool.apply_async(comic_archive_compress, args=(args,))
+    return multiproc['pool'].apply_async(comic_archive_compress, args=(args,))
 
 
 def optimize_file(filename_full, arguments, multiproc, optimize_after):
@@ -904,7 +913,6 @@ def optimize_all_files(multiproc, arguments):
     # Init records
     record_dirs = set()
     cwd_files = set()
-    full_result_set = set()
 
     for filename in arguments.paths:
         # Record dirs to put timestamps in later
@@ -916,28 +924,17 @@ def optimize_all_files(multiproc, arguments):
         #   Otherwise add the files to the list to do next
         path_dn, path_fn = os.path.split(os.path.realpath(filename))
         if path_dn != cwd:
-            result_set = optimize_files_after(path_dn, arguments,
-                                              [path_fn], multiproc)
-            full_result_set.union(result_set)
+            optimize_files_after(path_dn, arguments,
+                                 [path_fn], multiproc)
         else:
             cwd_files.add(path_fn)
 
     # Optimize immediate descendants with optimize after computed from
     # the current directory
     if len(cwd_files):
-        result_set = optimize_files_after(cwd, arguments, cwd_files,
-                                          multiproc)
-        full_result_set.union(result_set)
+        optimize_files_after(cwd, arguments, cwd_files, multiproc)
 
-    # Wait for all files to finish compressing
-    for result in full_result_set:
-        result.wait()
-
-    # Write timestamps
-    pool = multiproc['pool']
-    for filename in record_dirs:
-        args = (filename, arguments)
-        pool.apply_async(record_timestamp, args=(args,))
+    return record_dirs
 
 
 def run_main(raw_arguments):
@@ -956,13 +953,16 @@ def run_main(raw_arguments):
                  'nag_about_gifs': nag_about_gifs}
 
     # Optimize Files
-    optimize_all_files(multiproc, arguments)
+    record_dirs = optimize_all_files(multiproc, arguments)
 
     # Shut down multiprocessing
-    pool = multiproc['pool']
     pool.close()
     pool.join()
 
+    # Write timestamps
+    for filename in record_dirs:
+        record_timestamp(filename, arguments)
+
     # Finish by reporting totals
     report_totals(multiproc['in'].get(), multiproc['out'].get(),
                   arguments, multiproc['nag_about_gifs'].get())
